@@ -1,5 +1,4 @@
 import asyncio
-import logging
 from typing import Text
 
 import click
@@ -61,7 +60,7 @@ def list_apps():
     "--name",
     type=click.STRING,
     required=True,
-    help="Name of the app you want to install. Has to be one of nlu, ner",
+    help="Code of the app you want to install. To get App codes try: neuralspace list-apps",
 )
 @click.option(
     "-l", "--log-level", type=click.Choice(["INFO", "DEBUG", "ERROR"]), default="INFO"
