@@ -13,7 +13,7 @@ from rich.progress import (
 )
 from rich.text import Text as Text_render
 
-__NEURALSPACE_URL = "https://ns-platform-staging.uksouth.cloudapp.azure.com"
+__NEURALSPACE_URL = "https://platform.neuralspace.ai"
 NEURALSPACE_URL_ENV_VAR = "NEURALSPACE_URL"
 LOGIN_URL = "api/auth/login"
 INSTALL_APP_URL = "api/app/install"
@@ -122,7 +122,7 @@ METRICS = "metrics"
 INTENT_CLASSIFIER_METRICS = "intentClassifierPerformance"
 INTENT_ACCURACY = "i_acc"
 NER_METRICS = "nerPerformance"
-ENTITY_ACC = "e_acc"
+ENTITY_PARTIAL_F1 = "e_f1_partial"
 TRAINING_TIME = "trainingTime"
 ENTITY = "entity"
 MESSAGE = "message"
@@ -165,10 +165,12 @@ END = "end"
 START = "start"
 CONFIDENCE = "confidence"
 INTENT_RANKING = "intent_ranking"
+NO_OF_TRAINING_JOBS = "noOfTrainingJob"
 # supported entity types
 NER_TYPES = [PRE_TRAINED, LOOKUP, SYNONYM, REGEX]
 USER_DEFINED_ENTITY_TYPES = [LOOKUP, SYNONYM, REGEX]
 
+
 # Follow up Commands
 CREATE_PROJECT_COMMAND = "neuralspace nlu create-project --help"
 UPLOAD_DATASET_COMMAND = "neuralspace nlu upload-dataset --help"
@@ -176,7 +178,8 @@ INSTALL_APP_COMMAND = "neuralspace install-app --help"
 TRAIN_MODEL_COMMAND = "neuralspace nlu train --help"
 DEPLOY_MODEL_COMMAND = "neuralspace nlu deploy --help"
 PARSE_MODEL_COMMAND = "neuralspace nlu parse --help"
-
+STATUS_MODEL_COMMAND = "neuralspace nlu model-status --help"
+LIST_MODELS_COMMAND = "neuralspace nlu list-models --help"
 # checking command
 
 APP_IS_INSTALLED = "App is already installed"
