@@ -41,8 +41,8 @@ from neuralspace.constants import (
     ENTITIES,
     ENTITIES_FILE,
     ENTITY,
-    ENTITY_ACC,
     ENTITY_ID,
+    ENTITY_PARTIAL_F1,
     ENTITY_TYPE,
     ERROR,
     EXAMPLE,
@@ -69,6 +69,7 @@ from neuralspace.constants import (
     LANGUAGES,
     LAST_STATUS_UPDATED,
     LIST_ENTITY_URL,
+    LIST_MODELS_COMMAND,
     MESSAGE,
     METRICS,
     MODEL_ID,
@@ -78,6 +79,7 @@ from neuralspace.constants import (
     NAME,
     NAME_GENERATOR_CONFIG,
     NER_METRICS,
+    NO_OF_TRAINING_JOBS,
     NUMBER_OF_EXAMPLES,
     NUMBER_OF_INTENTS,
     NUMBER_OF_MODELS,
@@ -109,6 +111,7 @@ from neuralspace.constants import (
     SOUP,
     START,
     START_INDEX,
+    STATUS_MODEL_COMMAND,
     SYNONYMS,
     TEXT,
     TIMED_OUT,
@@ -120,7 +123,6 @@ from neuralspace.constants import (
     UPLOAD_DATASET_COMMAND,
     USER_DEFINED_ENTITY_TYPES,
     WRITING,
-    MODEL_ID_key,
     neuralspace_home,
     neuralspace_url,
     progress_bar,
@@ -138,6 +140,7 @@ from neuralspace.nlu.constants import (
     CREATE_ENTITY_URL,
     CREATE_EXAMPLE_URL,
     CREATE_PROJECT_URL,
+    DEFAULT_RASA_TRAINING_JOBS,
     DELETE_ENTITY_EXAMPLES_URL,
     DELETE_ENTITY_URL,
     DELETE_EXAMPLE_URL,
@@ -154,6 +157,7 @@ from neuralspace.nlu.constants import (
     SINGLE_MODEL_DETAILS_URL,
     TRAIN_MODEL_URL,
 )
+from neuralspace.nlu.utils import print_model_ids
 from neuralspace.utils import get_auth_token, is_success_status, print_ner_response
 
 console = Console()
@@ -256,7 +260,7 @@ async def create_project(project_name: Text, languages: List[Text]) -> Dict[Text
                 f" {DARK_ORANGE_START}{UPLOAD_DATASET_COMMAND}{DARK_ORANGE_END}"
             )
         else:
-            console.print(f"> {ERROR} {CROSS} Failed to create project")
+            console.print(f"> {ERROR} {CROSS} Failed to create   project")
             console.print(
                 f'''> Reason for failure {SAD_SMILEY}:- " {RED_START}{json_response[DATA]['error']}{RED_END} "'''
             )
@@ -463,7 +467,7 @@ def print_models_table(models: Dict[Text, Any], verbose: bool):
         table.add_column("Training Status")
         table.add_column("Replicas")
         table.add_column("Intent Acc")
-        table.add_column("Entity Acc")
+        table.add_column("Entity Partial F1")
         table.add_column("Training Time (sec)")
         table.add_column("Last Updated")
         table.add_column("Training Message")
@@ -482,7 +486,7 @@ def print_models_table(models: Dict[Text, Any], verbose: bool):
                 )
                 if data[TRAINING_STATUS] == COMPLETED
                 else "0.0",
-                "{:.3f}".format(data[METRICS][NER_METRICS][ENTITY_ACC])
+                "{:.3f}".format(data[METRICS][NER_METRICS][ENTITY_PARTIAL_F1])
                 if data[TRAINING_STATUS] == COMPLETED
                 else "0.0",
                 str(data[TRAINING_TIME])
@@ -540,22 +544,25 @@ async def list_models(
 
 async def delete_examples(example_ids: List[Text]) -> Dict[Text, Any]:
     console.print(f"> {INFO} {BIN} Deleting Example with id: {example_ids}")
-    payload = {EXAMPLE_ID: example_ids}
-    HEADERS = copy(COMMON_HEADERS)
-    HEADERS[AUTHORIZATION] = get_auth_token()
-    async with get_async_http_session().delete(
-        url=f"{neuralspace_url()}/{DELETE_EXAMPLE_URL}",
-        data=json.dumps(payload, ensure_ascii=False),
-        headers=HEADERS,
-    ) as response:
-        json_response = await response.json(encoding="utf-8")
-        if is_success_status(response.status):
-            console.print(f"> {INFO} {GREEN_TICK} Successfully deleted example!")
-        else:
-            console.print(f"> {ERROR} {CROSS} Failed to delete examples")
-            console.print(
-                f'''> Reason for failure {SAD_SMILEY}: " {RED_START}{json_response[MESSAGE]}{RED_END} "'''
-            )
+    for examples_id in example_ids:
+        payload = {EXAMPLE_ID: examples_id}
+        HEADERS = copy(COMMON_HEADERS)
+        HEADERS[AUTHORIZATION] = get_auth_token()
+        async with get_async_http_session().delete(
+            url=f"{neuralspace_url()}/{DELETE_EXAMPLE_URL}",
+            data=json.dumps(payload, ensure_ascii=False),
+            headers=HEADERS,
+        ) as response:
+            json_response = await response.json(encoding="utf-8")
+            if is_success_status(response.status):
+                console.print(
+                    f"> {INFO} {GREEN_TICK} Successfully deleted example_id: {examples_id}"
+                )
+            else:
+                console.print(f"> {ERROR} {CROSS} Failed to delete examples")
+                console.print(
+                    f'''> Reason for failure {SAD_SMILEY}: " {RED_START}{json_response[MESSAGE]}{RED_END} "'''
+                )
     return json_response
 
 
@@ -695,11 +702,7 @@ async def wait_till_training_completes(
 
 
 async def train_model(
-    project_id: Text,
-    language: Text,
-    model_name: Text,
-    wait: bool = True,
-    wait_time: int = 1,
+    project_id: Text, language: Text, model_name: Text, training_jobs: int
 ) -> Tuple[Dict[Text, Any], Dict[Text, Any]]:
     console.print(
         f"> {INFO} Queuing training job for: \n"
@@ -707,7 +710,12 @@ async def train_model(
         f"> {INFO} Language: {language}\n"
         f"> {INFO} Model Name: {model_name}"
     )
-    payload = {PROJECT_ID: project_id, LANGUAGE: language, MODEL_NAME: model_name}
+    payload = {
+        PROJECT_ID: project_id,
+        LANGUAGE: language,
+        MODEL_NAME: model_name,
+        NO_OF_TRAINING_JOBS: training_jobs,
+    }
     HEADERS = copy(COMMON_HEADERS)
     HEADERS[AUTHORIZATION] = get_auth_token()
 
@@ -718,11 +726,15 @@ async def train_model(
     ) as response:
         json_response = await response.json(encoding="utf-8")
         if is_success_status(response.status):
-            console.print("> {INFO} Training job queued successfully")
-            model_id = json_response[DATA][MODEL_ID_key]
-            last_model_status = await wait_till_training_completes(
-                model_id, wait, wait_time
+            model_ids = json_response[DATA]
+            console.print(
+                f"> {INFO}  Successfully queued {len(model_ids)} training jobs."
             )
+            console.print(
+                f"To checkout the training status use: {STATUS_MODEL_COMMAND}"
+            )
+            print_model_ids(model_ids)
+            last_model_status = QUEUED
         else:
             console.print(f"> {ERROR} Failed to queue training job")
             console.print(f"> {ERROR} {json_response[MESSAGE]}")
@@ -769,9 +781,14 @@ async def deploy(model_id: Text, n_replicas: int) -> Dict[Text, Any]:
     ) as response:
         json_response = await response.json(encoding="utf-8")
         if is_success_status(response.status):
-            console.print(f"> {INFO} {GREEN_TICK} Model deployed successfully")
+            console.print(f"> {INFO} {GREEN_TICK} Model added to deployment queue.")
             console.print(
-                f"{FAST_FORWARD} To parse the model: {DARK_ORANGE_START}{PARSE_MODEL_COMMAND}{DARK_ORANGE_END}"
+                f"{FAST_FORWARD} Check for replicas in model status to know that the model got deployed: "
+                f"{DARK_ORANGE_START}{LIST_MODELS_COMMAND}{DARK_ORANGE_END}"
+            )
+            console.print(
+                f"{FAST_FORWARD}Once the model is deployed parse text using: "
+                f"{DARK_ORANGE_START}{PARSE_MODEL_COMMAND}{DARK_ORANGE_END}"
             )
         else:
             console.print(f"> {ERROR} {CROSS} Failed to deploy model")
@@ -786,7 +803,7 @@ def print_nlu_response(nlu_response: Dict[Text, Any], response_time: float):
     table.add_column("Text")
     table.add_column("Intent")
     table.add_column("Intent Confidence")
-    table.add_column("Response Time (sec)")
+    table.add_column("Response Time (m-sec)")
     table.add_row(
         nlu_response[DATA][TEXT],
         nlu_response[DATA][INTENT][NAME],
@@ -918,7 +935,11 @@ def upload_entity_sync(example: Dict[Text, Any]) -> requests.Response:
 
 
 def start_training(project_id: Text, language: Text) -> Dict[Text, Any]:
-    data = {PROJECT_ID: project_id, LANGUAGE: language}
+    data = {
+        PROJECT_ID: project_id,
+        LANGUAGE: language,
+        NO_OF_TRAINING_JOBS: DEFAULT_RASA_TRAINING_JOBS,
+    }
     url = f"{neuralspace_url()}/{TRAIN_MODEL_URL}"
     HEADERS = copy(COMMON_HEADERS)
     HEADERS[AUTHORIZATION] = get_auth_token()
