@@ -87,13 +87,16 @@ def nlu_get_languages(log_level: Text):
     loop.run_until_complete(get_async_http_session().close())
 
 
-@nlu.command(name="convert-dataset")
+@nlu.command(
+    name="convert-dataset",
+    help="To know more about the format and structure kindly refer https://docs.neuralspace.com",
+)
 @click.option(
     "-F",
     "--from-platform",
     type=click.Choice(["dialogflow", "rasa", "csv", "luis"], case_sensitive=False),
     required=True,
-    help="From where to convert data from [dialogflow, rasa, csv]",
+    help="From where to convert data from [dialogflow, rasa, csv, luis]",
 )
 @click.option(
     "-at",
@@ -150,6 +153,9 @@ def nlu_get_languages(log_level: Text):
     default=False,
     help="Will ignore if there is swapped columns in your nlu examples data(works with csv files only)",
 )
+@click.option(
+    "-l", "--log-level", type=click.Choice(["INFO", "DEBUG", "ERROR"]), default="INFO"
+)
 def converter(
     from_platform: Text,
     auto_tag_entities: bool,
@@ -160,7 +166,9 @@ def converter(
     output_path: Text,
     ignore_missing_examples: bool,
     ignore_swapped_columns: bool,
+    log_level: Text,
 ):
+    setup_logger(log_level=log_level)
     if entity_mapping is not False:
         if from_platform == "rasa":
             from neuralspace.nlu.converters.rasaconverter import RasaConverter
@@ -241,7 +249,8 @@ def converter(
     type=click.STRING,
     multiple=True,
     required=True,
-    help="List of languages. -L en -L de; You can add multiple languages",
+    help="Language code that you want to select for this project. To get the list of supported languages try:"
+    " neuralspace nlu get-languages",
 )
 @click.option(
     "-l", "--log-level", type=click.Choice(["INFO", "DEBUG", "ERROR"]), default="INFO"
@@ -538,29 +547,30 @@ def nlu_delete_example(example_id: List[Text], log_level: Text):
     help="Name of the model",
 )
 @click.option(
-    "-w",
-    "--wait",
-    is_flag=True,
-    default=True,
-    help="Wait for training to complete",
-)
-@click.option(
-    "-i",
-    "--wait-interval",
+    "-n",
+    "--training-jobs",
     type=click.INT,
     required=False,
     default=1,
-    help="Time to wait between consecutive polls.",
+    help="No of training jobs to be queued",
+)
+@click.option(
+    "-l", "--log-level", type=click.Choice(["INFO", "DEBUG", "ERROR"]), default="INFO"
 )
 def nlu_train_model(
-    project_id: Text, language: Text, model_name: Text, wait: bool, wait_interval: int
+    project_id: Text,
+    language: Text,
+    model_name: Text,
+    log_level: Text,
+    training_jobs: int,
 ):
+    setup_logger(log_level=log_level)
     print_logo()
     if model_name is None:
         model_name = randomname.get_name(**NAME_GENERATOR_CONFIG)
     loop = asyncio.new_event_loop()
     loop.run_until_complete(
-        train_model(project_id, language, model_name, wait, wait_time=wait_interval)
+        train_model(project_id, language, model_name, training_jobs)
     )
     loop.run_until_complete(get_async_http_session().close())
 
